'use client'

import React, { useState } from 'react'
import { motion } from 'framer-motion'

const SubscribeSection: React.FC = () => {
  const [email, setEmail] = useState('')

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()
    // Handle form submission here
    console.log('Submitted email:', email)
    setEmail('')
  }

  return (
    <section className="sbs-section py-16 px-4 bg-gradient-to-r from-yellow-300 via-orange-300 to-orange-400">
      <div className="sbs-container max-w-4xl mx-auto text-center">
        <motion.h2 
          className="sbs-title text-4xl md:text-5xl font-bold text-white mb-4"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
        >
          Stay Updated with Our Latest Features
        </motion.h2>
        <motion.p 
          className="sbs-subtitle text-white text-lg mb-8"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.2 }}
        >
          Subscribe to our newsletter and be the first to know about new features, updates, and special offers!
        </motion.p>
        <motion.form 
          className="sbs-form"
          onSubmit={handleSubmit}
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.4 }}
        >
          <div className="sbs-input-group flex flex-col sm:flex-row justify-center items-center gap-4">
            <motion.input
              type="email"
              placeholder="Enter your email"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              className="sbs-email-input w-full sm:w-96 px-4 py-3 rounded-full text-gray-800 focus:outline-none focus:ring-2 focus:ring-blue-500"
              whileFocus={{ scale: 1.05 }}
              transition={{ duration: 0.2 }}
            />
            <motion.button
              type="submit"
              className="sbs-submit-btn w-full sm:w-auto px-8 py-3 bg-gray-800 text-white rounded-full font-semibold hover:bg-gray-700 focus:outline-none focus:ring-2 focus:ring-gray-500"
              whileHover={{ scale: 1.05 }}
              whileTap={{ scale: 0.95 }}
            >
              Subscribe Now
            </motion.button>
          </div>
        </motion.form>
      </div>
      <motion.div 
        className="sbs-bottom-line w-full h-1 bg-pink-500 mt-16"
        initial={{ scaleX: 0 }}
        whileInView={{ scaleX: 1 }}
        viewport={{ once: true }}
        transition={{ duration: 0.8, delay: 0.6 }}
      />
    </section>
  )
}

export default SubscribeSection